.. _installation:

Installation
============

Python distribution
-------------------

*suppy* can be simply installed via pip:

.. code-block:: bash

    pip install suppy


*suppy* algorithms can also be run on the GPU. For this, the `cupy library <https://cupy.dev/>`_ is required.
For installation check your CUDA version and the `installation guide <https://docs.cupy.dev/en/stable/install.html>`_.

Alternatively the source code can be found and cloned from `GitHub TBD <>`_.


If you would like to contribute or have any question issues feel free to update the `GitHub repository <>`_.
